| Title: | Test CRAN/Bioconductor Mirror Speed |
|---|---|
| Description: | Testing CRAN and Bioconductor mirror speed by recording download time of 'src/base/COPYING' (for CRAN) and 'packages/release/bioc/html/ggtree.html' (for Bioconductor). |
| Authors: | Guangchuang Yu [aut, cre] (ORCID: <https://orcid.org/0000-0002-6485-8781>) |
| Maintainer: | Guangchuang Yu <[email protected]> |
| License: | Artistic-2.0 |
| Version: | 0.0.3 |
| Built: | 2026-05-15 09:36:00 UTC |
| Source: | https://github.com/yulab-smu/mirrorselect |
Access CRAN or Bioconductor mirror
get_mirror(repo = "CRAN", country = "global")get_mirror(repo = "CRAN", country = "global")
repo |
one of 'CRAN' or 'BioC' |
country |
specify the mirrors from a specific country. Default to 'global' without filtering. |
The mirror lists are obtained from https://cran.r-project.org/mirrors.html (CRAN) or https://bioconductor.org/BioC_mirrors.csv (Bioconductor). This function allows user to extract mirrors from a specific country using internet country code.
a vector of mirror urls
Guangchuang Yu
head(get_mirror())head(get_mirror())
test download speed of CRAN mirrors by recording download time for mirror/src/base/COPYING
mirrorselect(mirrors)mirrorselect(mirrors)
mirrors |
a vector of CRAN mirrors |
data frame with a column of mirror and second column of speed
Guangchuang Yu
m <- c("https://cloud.r-project.org/", "https://cran.ms.unimelb.edu.au/") if (yulab.utils::has_internet()) { x <- mirrorselect(m) head(x) }m <- c("https://cloud.r-project.org/", "https://cran.ms.unimelb.edu.au/") if (yulab.utils::has_internet()) { x <- mirrorselect(m) head(x) }